@@ -1,9 +1,9 @@
-use std::time::Duration;
+use core::time::Duration;
 
 use crate::builder::error::Error;
 use crate::peer_list::{PeerList, PeerListBuilder};
 use crate::supervisor::Instance;
-use crate::types::PeerId;
+use crate::verifier::types::PeerId;
 
 #[cfg(feature = "rpc-client")]
 use {
