@@ -1,9 +1,7 @@
 //! Predicates used in components contracts.
 
-use crate::{
-    store::LightStore,
-    types::{Height, LightBlock, Status, Time},
-};
+use crate::store::LightStore;
+use crate::verifier::types::{Height, LightBlock, Status, Time};
 
 use std::time::Duration;
 
